@@ -98,7 +98,7 @@ function sentryRefresh(){
           for (var i=groups.length-1, el, row; (el=groups[i]); i--) {
               var id = el[0];
               var data = el[1];
-              if (row = $('#group_' + id)) {
+              if ((row = $('#group_' + id))) {
                   row.remove();
                   $('#message_list').prepend(data.html);
                   if (row.attr('data-sentry-count') != data.count) {
@@ -106,7 +106,7 @@ function sentryRefresh(){
                   }
               } else {
                   $('#message_list').prepend(data.html);
-                  $('#group_' + id).addClass('fresh')
+                  $('#group_' + id).addClass('fresh');
               }
           }
           $('#message_list .fresh').css('background-color', '#ccc').animate({backgroundColor: '#fff'}, 1200, function() { 
@@ -114,13 +114,13 @@ function sentryRefresh(){
           });
           // make sure we limit the number shown
           var count = 0;
-          $('#message_list').each(function(){
+          $('#message_list li').each(function(){
               count++;
               if (count > 50) {
                   $(this).remove();
               }
-          })
+          });
+          setTimeout(sentryRefresh, 3000);          
       }
     });
-    setTimeout('sentryRefresh()', 3000);
-}
\ No newline at end of file
+}
